@@ -684,6 +684,62 @@ set_user_pincode (GtkWidget *button)
 	}
 }
 
+static char *
+get_default_adapter_address (void)
+{
+	BluetoothClient *client;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	gboolean cont;
+
+	client = bluetooth_client_new ();
+	model = bluetooth_client_get_adapter_model (client);
+	cont = gtk_tree_model_get_iter_first(model, &iter);
+
+	while (cont == TRUE) {
+		char *address;
+		gboolean is_default;
+
+		gtk_tree_model_get (model, &iter,
+				    BLUETOOTH_COLUMN_ADDRESS, &address,
+				    BLUETOOTH_COLUMN_DEFAULT, &is_default, -1);
+
+		if (is_default == TRUE) {
+			g_object_unref (model);
+			g_object_unref (client);
+			return address;
+		}
+
+		g_free (address);
+
+		cont = gtk_tree_model_iter_next (model, &iter);
+	}
+
+	g_object_unref (model);
+	g_object_unref (client);
+
+	return NULL;
+}
+
+static char *
+pin_from_adapter (const char *bdaddr)
+{
+	char **items;
+	GString *s;
+	char *ret;
+	int i;
+
+	items = g_strsplit (bdaddr, ":", -1);
+	g_assert (g_strv_length (items) == 6);
+	s = g_string_new ("$");
+	for (i = 5; i >= 0; i--)
+		g_string_append (s, items[i]);
+	g_strfreev (items);
+	ret = g_string_free (s, FALSE);
+
+	return ret;
+}
+
 void
 select_device_changed (BluetoothChooser *selector,
 		       const char *address,
@@ -736,6 +792,14 @@ select_device_changed (BluetoothChooser *selector,
 				pincode = g_strndup(target_pincode, max_digits);
 			else
 				pincode = g_strdup(target_pincode);
+		} else if (g_str_equal (pincode, "WII")) {
+			char *default_adapter;
+
+			g_free (pincode);
+			default_adapter = get_default_adapter_address ();
+			pincode = pin_from_adapter (default_adapter);
+			g_free (default_adapter);
+			automatic_pincode = TRUE;
 		} else if (target_ssp == FALSE) {
 			automatic_pincode = TRUE;
 		}
@@ -800,25 +864,11 @@ page_func (gint current_page,
 static GtkAssistant *
 create_wizard (void)
 {
-	const char *pages[] = {
-		"page_intro",
-		"page_search",
-		"page_connecting",
-		"page_setup",
-		"page_ssp_setup",
-		"page_failure",
-		"page_finishing",
-		"page_summary",
-	};
-	guint i;
-
 	GtkAssistant *assistant;
 	GError *err = NULL;
 	GtkWidget *combo, *page_intro;
 	GtkTreeModel *model;
 	GtkCellRenderer *renderer;
-	GdkPixbuf *pixbuf;
-	int height;
 
 	builder = gtk_builder_new ();
 	if (gtk_builder_add_from_file (builder, "wizard.ui", NULL) == 0) {
@@ -897,15 +947,6 @@ create_wizard (void)
 	label_summary = W("label_summary");
 	extra_config_vbox = W("extra_config_vbox");
 
-	/* Set page icons */
-	gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, NULL, &height);
-	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					   "bluetooth", height, 0, NULL);
-	for (i = 0; i < G_N_ELEMENTS (pages); i++)
-		gtk_assistant_set_page_header_image (assistant, W(pages[i]), pixbuf);
-	if (pixbuf != NULL)
-		g_object_unref (pixbuf);
-
 	/* PIN dialog */
 	pin_dialog = W("pin_dialog");
 	radio_auto = W("radio_auto");
